@@ -10,8 +10,9 @@ class ParseArgs(TestCase):
     @parameterized.expand([
         ('all',),
         ('schema',),
+        ('data',),
     ])
-    def test_schema_dumper(self, command_name):
+    def test_query_dumper(self, command_name):
         arguments = [command_name, 'table-name']
         actual = parse_args(arguments)
         eq_(actual.table_name, 'table-name')
@@ -25,23 +26,9 @@ class ParseArgs(TestCase):
         ok_(hasattr(actual, 'lines_for_inference'))
         ok_(hasattr(actual, 'command'))
         ok_(hasattr(actual, 'query_engine'))
+        ok_(hasattr(actual, 'patterns'))
         ok_(hasattr(actual, 'index_types'))
 
-    @parameterized.expand([
-        ('data',),
-    ])
-    def test_insertion_dumper(self, command_name):
-        arguments = [command_name, 'table-name']
-        actual = parse_args(arguments)
-        eq_(actual.table_name, 'table-name')
-        ok_(hasattr(actual, 'in_file'))
-        ok_(hasattr(actual, 'out_file'))
-        ok_(hasattr(actual, 'null'))
-        ok_(hasattr(actual, 'delimiter'))
-        ok_(hasattr(actual, 'rebuild'))
-        ok_(hasattr(actual, 'command'))
-        ok_(hasattr(actual, 'query_engine'))
-
     @parameterized.expand([
         (['-t', '1-type'],),
         (['--column-type', '0:type'],),
